Coverage for /home/agp/Documents/me/code/brotation/brotation/cli.py: 32%

# Coverage for /home/agp/Documents/me/code/brotation/brotation/cli.py : 32%

## 22 statements 7 run 15 missing 2 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1"""Console script for brotation."""

2 import wingdbstub

3 import sys

4 import click

5

6

7@click.group()

8 def backup():

9 pass

10

11

12@backup.command()

13@click.option('-w', '--where', 'where')

14@click.option('-f', '--folders', 'folders')

15 def backup():

16 """Command on cli1"""

17

18

19@click.group()

20 def restore():

21 pass

22

23

24@restore.command()

25 def cmd2():

26 """Command on cli2"""

27

28

29 main = click.CommandCollection(sources=[backup, restore])

30

31 if __name__ == '__main__':

32 sys.exit(main()) # pragma: no cover

33

34

35@click.command()

36 def main(where, folders):

37 click.echo(where)

38 click.echo(folders)

39

40

41# @click.command()

42# def main(args=None):

43 #"""Console script for brotation."""

44 # click.echo("Replace this message by putting your code into "

45 # "brotation.cli.main")

46 #click.echo("See click documentation at https://click.palletsprojects.com/")

47 # return 0

48

49

50 if __name__ == "__main__":

51 sys.exit(main()) # pragma: no cover